==> react-molecule-autosuggest-1.14.0.tgz: package/lib/components/SingleSelection.js <==
/* eslint-disable react/prop-types */
import React from 'react';
import MoleculeDropdownList from '@s-ui/react-molecule-dropdown-list';
import AtomInput from '@s-ui/react-atom-input';
import withClearUI from '../hoc/withClearUI';
var AtomInputWithClearUI = withClearUI(AtomInput);

var MoleculeAutosuggestSingleSelection = function MoleculeAutosuggestSingleSelection(_ref) {
  var id = _ref.id,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value,
      children = _ref.children,
      isOpen = _ref.isOpen,
      onToggle = _ref.onToggle,
      onChange = _ref.onChange,
      onClickRightIcon = _ref.onClickRightIcon,
      onInputKeyDown = _ref.onInputKeyDown,
      onSelect = _ref.onSelect,
      size = _ref.size,
      innerRefInput = _ref.innerRefInput,
      refMoleculeAutosuggest = _ref.refMoleculeAutosuggest,
      rightIcon = _ref.rightIcon,
      iconClear = _ref.iconClear,
      placeholder = _ref.placeholder,
      disabled = _ref.disabled,
      required = _ref.required;

  var handleSelection = function handleSelection(ev, _ref2) {
    var value = _ref2.value;
    onChange(ev, {
      value: value
    });
    onSelect(ev, {
      value: value
    });
    onToggle(ev, {
      isOpen: false
    });
    refMoleculeAutosuggest.current.focus();
  };

  var handleChange = function handleChange(ev, _ref3) {
    var value = _ref3.value;
    onChange(ev, {
      value: value
    });
    onToggle(ev, {
      isOpen: true
    });
  };

  var handleClear = function handleClear() {
    onChange(null, {
      value: ''
    });
  };

  var handleRightClick = function handleRightClick(ev) {
    onClickRightIcon(ev, {
      value: value
    });
  };

  return React.createElement(React.Fragment, null, React.createElement(AtomInputWithClearUI, {
    id: id,
    value: value,
    isVisibleClear: value,
    onClickClear: handleClear,
    onChange: handleChange,
    iconClear: !disabled && iconClear,
    rightIcon: rightIcon,
    onClickRightIcon: handleRightClick,
    reference: innerRefInput,
    placeholder: placeholder,
    onKeyDown: onInputKeyDown,
    disabled: disabled,
    required: required
  }), value && React.createElement(MoleculeDropdownList, {
    size: size,
    visible: isOpen && React.Children.count(children) > 0,
    onSelect: handleSelection,
    value: value,
    highlightQuery: value
  }, children));
};

MoleculeAutosuggestSingleSelection.displayName = 'MoleculeAutosuggestSingleSelection';
MoleculeAutosuggestSingleSelection.defaultProps = {
  value: ''
};
export default MoleculeAutosuggestSingleSelection;

==> react-molecule-autosuggest-1.15.0.tgz: package/lib/components/SingleSelection.js <==
/* eslint-disable react/prop-types */
import React from 'react';
import MoleculeDropdownList from '@s-ui/react-molecule-dropdown-list';
import AtomInput from '@s-ui/react-atom-input';
import withClearUI from '../hoc/withClearUI';
var AtomInputWithClearUI = withClearUI(AtomInput);

var MoleculeAutosuggestSingleSelection = function MoleculeAutosuggestSingleSelection(_ref) {
  var id = _ref.id,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? '' : _ref$value,
      children = _ref.children,
      isOpen = _ref.isOpen,
      onToggle = _ref.onToggle,
      onChange = _ref.onChange,
      onClickRightIcon = _ref.onClickRightIcon,
      onInputKeyDown = _ref.onInputKeyDown,
      onSelect = _ref.onSelect,
      size = _ref.size,
      innerRefInput = _ref.innerRefInput,
      refMoleculeAutosuggest = _ref.refMoleculeAutosuggest,
      rightIcon = _ref.rightIcon,
      iconClear = _ref.iconClear,
      placeholder = _ref.placeholder,
      disabled = _ref.disabled,
      required = _ref.required,
      tabIndex = _ref.tabIndex;

  var handleSelection = function handleSelection(ev, _ref2) {
    var value = _ref2.value;
    onChange(ev, {
      value: value
    });
    onSelect(ev, {
      value: value
    });
    onToggle(ev, {
      isOpen: false
    });
    refMoleculeAutosuggest.current.focus();
  };

  var handleChange = function handleChange(ev, _ref3) {
    var value = _ref3.value;
    onChange(ev, {
      value: value
    });
    onToggle(ev, {
      isOpen: true
    });
  };

  var handleClear = function handleClear() {
    onChange(null, {
      value: ''
    });
  };

  var handleRightClick = function handleRightClick(ev) {
    onClickRightIcon(ev, {
      value: value
    });
  };

  return React.createElement(React.Fragment, null, React.createElement(AtomInputWithClearUI, {
    id: id,
    value: value,
    isVisibleClear: value,
    onClickClear: handleClear,
    onChange: handleChange,
    iconClear: !disabled && iconClear,
    rightIcon: rightIcon,
    onClickRightIcon: handleRightClick,
    reference: innerRefInput,
    placeholder: placeholder,
    onKeyDown: onInputKeyDown,
    disabled: disabled,
    required: required,
    tabIndex: tabIndex
  }), value && React.createElement(MoleculeDropdownList, {
    size: size,
    visible: isOpen && React.Children.count(children) > 0,
    onSelect: handleSelection,
    value: value,
    highlightQuery: value
  }, children));
};

MoleculeAutosuggestSingleSelection.displayName = 'MoleculeAutosuggestSingleSelection';
MoleculeAutosuggestSingleSelection.defaultProps = {
  value: ''
};
export default MoleculeAutosuggestSingleSelection;
